@@ -6,7 +6,7 @@ use Regexp::Grammars;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 # ABSTRACT: Parse DOS .bat and .cmd files
 
@@ -17,9 +17,9 @@ has 'grammar' => (
            <nocontext:>
            <File>
     
-           <rule: File> (?:<[Lines]>\n)*
+           <rule: File> (?:<[Lines]>)*
 
-           <rule: Lines> <Comment> | <Label> | <Statement> 
+           <rule: Lines> (?: <Comment> | <Label> | <Statement> )\s*\n
 
            <rule: Comment> \:\:<Text=Token> | REM <Text=Token>
 
@@ -27,7 +27,7 @@ has 'grammar' => (
 
            <rule: Statement> \@?<Command>
            
-           <rule: Command> (?:<SpecialCommand> || <SimpleCommand=Token>)
+           <rule: Command> (?: <SpecialCommand> | <SimpleCommand=Token> )
 
            <rule: SpecialCommand> <If> | <Call> | <For> | <Goto> | <Set> | <Echo>
 
@@ -59,8 +59,8 @@ has 'grammar' => (
 
            <token: Literal> [^\s]+
 
-           <token: Token> [^\n]*
-
+           <token: Token> [^\n]*?
+           
            <token: LabelIdentifier> [^\n\s\:]*
 
         }xmi;
@@ -106,7 +106,7 @@ App::BatParser - Parse DOS .bat and .cmd files
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 DESCRIPTION
 
